==> core-0.0.35.tgz: package/src/components/Switch/props.ts <==
/**
 * File: /src/components/Switch/props.ts
 * Project: @native-theme-ui/core
 * File Created: 05-07-2022 06:24:30
 * Author: Clay Risser
 * -----
 * Last Modified: 10-09-2022 12:57:11
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { StyledBoxProps } from "./index";
import { createUseSplitProps, splitPropsGroups } from "../../util";
import { Sx } from "dripsy";

export type BasePropsBucket = StyledBoxProps;

export type SwitchPropsBucket = {
  checked?: boolean;
  disabled?: boolean;
  gutter?: number;
  label?: string;
  name?: string;
  size?: number;
};

export type CustomPropsBucket = {
  defaultChecked?: boolean;
};

export const useSplitProps = createUseSplitProps<
  SwitchProps,
  {
    baseProps: BasePropsBucket;
    checkboxProps: SwitchPropsBucket;
    customProps: CustomPropsBucket;
  },
  {
    baseSx: Sx;
    innerSx: Sx;
    voidSx: Sx;
  },
  {
    baseStyle: Record<string, unknown>;
    innerStyle: Record<string, unknown>;
    voidStyle: Record<string, unknown>;
  }
>(
  {
    checkboxProps: ["checked", "disabled", "name"],
    customProps: ["defaultChecked"],
  },
  {
    voidSx: splitPropsGroups.sx.padding,
    innerSx: splitPropsGroups.sx.inner,
  }
);

export type SwitchProps = BasePropsBucket &
  SwitchPropsBucket &
  CustomPropsBucket;

==> core-0.1.0.tgz: package/src/components/Switch/props.ts <==
/**
 * File: /src/components/Switch/props.ts
 * Project: @native-theme-ui/core
 * File Created: 05-07-2022 06:24:30
 * Author: Clay Risser
 * -----
 * Last Modified: 10-09-2022 12:57:11
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { StyledBoxProps } from './index';
import { createUseSplitProps, splitPropsGroups } from '../../util';
import { Sx } from 'dripsy';

export type BasePropsBucket = StyledBoxProps;

export type SwitchPropsBucket = {
  checked?: boolean;
  disabled?: boolean;
  gutter?: number;
  label?: string;
  name?: string;
  size?: number;
};

export type CustomPropsBucket = {
  defaultChecked?: boolean;
};

export const useSplitProps = createUseSplitProps<
  SwitchProps,
  {
    baseProps: BasePropsBucket;
    checkboxProps: SwitchPropsBucket;
    customProps: CustomPropsBucket;
  },
  {
    baseSx: Sx;
    innerSx: Sx;
    voidSx: Sx;
  },
  {
    baseStyle: Record<string, unknown>;
    innerStyle: Record<string, unknown>;
    voidStyle: Record<string, unknown>;
  }
>(
  {
    checkboxProps: ['checked', 'disabled', 'name'],
    customProps: ['defaultChecked'],
  },
  {
    voidSx: splitPropsGroups.sx.padding,
    innerSx: splitPropsGroups.sx.inner,
  },
);

export type SwitchProps = BasePropsBucket & SwitchPropsBucket & CustomPropsBucket;
